Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(7)

Unified Diff: editor/tools/plugins/com.google.dart.tools.ui/src/com/google/dart/tools/ui/internal/refactoring/RenameSupport_OLD.java

Issue 12340077: Initial binding of RenameRefactoring service to Eclipse. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 7 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: editor/tools/plugins/com.google.dart.tools.ui/src/com/google/dart/tools/ui/internal/refactoring/RenameSupport_OLD.java
diff --git a/editor/tools/plugins/com.google.dart.tools.ui/src/com/google/dart/tools/ui/internal/refactoring/RenameSupport.java b/editor/tools/plugins/com.google.dart.tools.ui/src/com/google/dart/tools/ui/internal/refactoring/RenameSupport_OLD.java
similarity index 89%
copy from editor/tools/plugins/com.google.dart.tools.ui/src/com/google/dart/tools/ui/internal/refactoring/RenameSupport.java
copy to editor/tools/plugins/com.google.dart.tools.ui/src/com/google/dart/tools/ui/internal/refactoring/RenameSupport_OLD.java
index ebfbec399f2389b1a6249b5b43e38aadb4a6f7e1..ba3adb5628d9d22ec355b5dad8284fafe79a2e5e 100644
--- a/editor/tools/plugins/com.google.dart.tools.ui/src/com/google/dart/tools/ui/internal/refactoring/RenameSupport.java
+++ b/editor/tools/plugins/com.google.dart.tools.ui/src/com/google/dart/tools/ui/internal/refactoring/RenameSupport_OLD.java
@@ -43,7 +43,7 @@ import com.google.dart.tools.internal.corext.refactoring.tagging.INameUpdating;
import com.google.dart.tools.ui.DartUIMessages;
import com.google.dart.tools.ui.internal.refactoring.reorg.RenameRefactoringWizard;
import com.google.dart.tools.ui.internal.refactoring.reorg.RenameUserInterfaceManager;
-import com.google.dart.tools.ui.internal.refactoring.reorg.RenameUserInterfaceStarter;
+import com.google.dart.tools.ui.internal.refactoring.reorg.RenameUserInterfaceStarter_OLD;
import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.IStatus;
@@ -65,7 +65,7 @@ import java.lang.reflect.InvocationTargetException;
*
* @coverage dart.editor.ui.refactoring.ui
*/
-public class RenameSupport {
+public class RenameSupport_OLD {
/**
* Flag indicating that DartDoc comments are to be updated as well.
@@ -112,10 +112,10 @@ public class RenameSupport {
* @param flags flags controlling additional parameters. Valid flags are
* <code>UPDATE_REFERENCES</code>, and <code>UPDATE_TEXTUAL_MATCHES</code>, or their
* bitwise OR, or <code>NONE</code>.
* @return the {@link RenameSupport}.
* @throws CoreException if an unexpected error occurred while creating the {@link RenameSupport}.
*/
- public static RenameSupport create(CompilationUnit unit, String newName, int flags)
+ public static RenameSupport_OLD create(CompilationUnit unit, String newName, int flags)
throws CoreException {
// TODO(scheglov) implement
throw new RuntimeException("Not implemented");
@@ -128,11 +128,11 @@ public class RenameSupport {
*
* @param type the {@link DartClassTypeAlias} to be renamed, not <code>null</code>.
* @param newName the new name, not <code>null</code>.
- * @return the {@link RenameSupport}.
+ * @return the {@link RenameSupport_OLD}.
*/
- public static RenameSupport create(DartClassTypeAlias type, String newName) {
+ public static RenameSupport_OLD create(DartClassTypeAlias type, String newName) {
DartRenameProcessor processor = new RenameClassTypeAliasProcessor(type);
- return new RenameSupport(processor, newName, 0);
+ return new RenameSupport_OLD(processor, newName, 0);
}
/**
@@ -140,16 +140,16 @@ public class RenameSupport {
*
* @param function the {@link DartFunction} to be renamed, not <code>null</code>.
* @param newName the function's new name, not <code>null</code>.
- * @return the {@link RenameSupport}.
+ * @return the {@link RenameSupport_OLD}.
*/
- public static RenameSupport create(DartFunction function, String newName) {
+ public static RenameSupport_OLD create(DartFunction function, String newName) {
DartRenameProcessor processor;
if (function.isLocal()) {
processor = new RenameLocalFunctionProcessor(function);
} else {
processor = new RenameFunctionProcessor(function);
}
- return new RenameSupport(processor, newName, 0);
+ return new RenameSupport_OLD(processor, newName, 0);
}
/**
@@ -157,19 +157,19 @@ public class RenameSupport {
*
* @param type the {@link DartFunctionTypeAlias} to be renamed, not <code>null</code>.
* @param newName the new name, not <code>null</code>.
- * @return the {@link RenameSupport}.
+ * @return the {@link RenameSupport_OLD}.
*/
- public static RenameSupport create(DartFunctionTypeAlias type, String newName) {
+ public static RenameSupport_OLD create(DartFunctionTypeAlias type, String newName) {
DartRenameProcessor processor = new RenameFunctionTypeAliasProcessor(type);
- return new RenameSupport(processor, newName, 0);
+ return new RenameSupport_OLD(processor, newName, 0);
}
/**
* Creates a new rename support for the given {@link DartImport}.
*/
- public static RenameSupport create(DartImport imprt, String newName) throws CoreException {
+ public static RenameSupport_OLD create(DartImport imprt, String newName) throws CoreException {
DartRenameProcessor processor = new RenameImportProcessor(imprt);
- return new RenameSupport(processor, newName, 0);
+ return new RenameSupport_OLD(processor, newName, 0);
}
/**
@@ -180,10 +180,10 @@ public class RenameSupport {
* new name is provided.
* @param flags flags controlling additional parameters. Valid flags are
* <code>UPDATE_REFERENCES</code> or <code>NONE</code>.
* @return the {@link RenameSupport}.
* @throws CoreException if an unexpected error occurred while creating the {@link RenameSupport}.
*/
- public static RenameSupport create(DartProject project, String newName, int flags)
+ public static RenameSupport_OLD create(DartProject project, String newName, int flags)
throws CoreException {
// TODO(scheglov) implement
throw new RuntimeException("Not implemented");
@@ -196,11 +196,11 @@ public class RenameSupport {
*
* @param parameter the {@link DartTypeParameter} to be renamed, not <code>null</code>.
* @param newName the new name, not <code>null</code>.
- * @return the {@link RenameSupport}.
+ * @return the {@link RenameSupport_OLD}.
*/
- public static RenameSupport create(DartTypeParameter parameter, String newName) {
+ public static RenameSupport_OLD create(DartTypeParameter parameter, String newName) {
DartRenameProcessor processor = new RenameTypeParameterProcessor(parameter);
- return new RenameSupport(processor, newName, 0);
+ return new RenameSupport_OLD(processor, newName, 0);
}
/**
@@ -209,10 +209,10 @@ public class RenameSupport {
* @param variable the {@link DartVariableDeclaration} to be renamed.
* @param newName the variable's new name. <code>null</code> is a valid value indicating that no
* new name is provided.
* @return the {@link RenameSupport}.
* @throws CoreException if an unexpected error occurred while creating the {@link RenameSupport}.
*/
- public static RenameSupport create(DartVariableDeclaration variable, String newName)
+ public static RenameSupport_OLD create(DartVariableDeclaration variable, String newName)
throws CoreException {
DartRenameProcessor processor;
if (variable.isGlobal()) {
@@ -220,7 +220,7 @@ public class RenameSupport {
} else {
processor = new RenameLocalVariableProcessor(variable);
}
- return new RenameSupport(processor, newName, 0);
+ return new RenameSupport_OLD(processor, newName, 0);
}
/**
@@ -228,11 +228,11 @@ public class RenameSupport {
*
* @param field the {@link Field} to be renamed, not <code>null</code>.
* @param newName the field's new name, not <code>null</code>.
- * @return the {@link RenameSupport}.
+ * @return the {@link RenameSupport_OLD}.
*/
- public static RenameSupport create(Field field, String newName) {
+ public static RenameSupport_OLD create(Field field, String newName) {
DartRenameProcessor processor = new RenameFieldProcessor(field);
- return new RenameSupport(processor, newName, 0);
+ return new RenameSupport_OLD(processor, newName, 0);
}
// /**
@@ -252,11 +252,11 @@ public class RenameSupport {
*
* @param method the {@link Method} to be renamed, not <code>null</code>.
* @param newName the method's new name, not <code>null</code>.
- * @return the {@link RenameSupport}.
+ * @return the {@link RenameSupport_OLD}.
*/
- public static RenameSupport create(Method method, String newName) {
+ public static RenameSupport_OLD create(Method method, String newName) {
DartRenameProcessor processor = new RenameMethodProcessor(method);
- return new RenameSupport(processor, newName, 0);
+ return new RenameSupport_OLD(processor, newName, 0);
}
/**
@@ -265,12 +265,12 @@ public class RenameSupport {
* @param type the {@link Type} to be renamed.
* @param newName the type's new name. <code>null</code> is a valid value indicating that no new
* name is provided.
* @return the {@link RenameSupport}.
* @throws CoreException if an unexpected error occurred while creating the {@link RenameSupport}.
*/
- public static RenameSupport create(Type type, String newName) throws CoreException {
+ public static RenameSupport_OLD create(Type type, String newName) throws CoreException {
DartRenameProcessor processor = new RenameTypeProcessor(type);
- return new RenameSupport(processor, newName, 0);
+ return new RenameSupport_OLD(processor, newName, 0);
}
private static void initialize(DartRenameProcessor processor, String newName, int flags) {
@@ -306,8 +306,8 @@ public class RenameSupport {
* @param flags flags controlling additional parameters. Valid flags are
* <code>UPDATE_REFERENCES</code>, and <code>UPDATE_TEXTUAL_MATCHES</code>, or their
* bitwise OR, or <code>NONE</code>.
* @return the {@link RenameSupport}.
* @throws CoreException if an unexpected error occurred while creating the {@link RenameSupport}.
*/
// public static RenameSupport create(IPackageFragment fragment, String newName, int flags) throws CoreException {
// JavaRenameProcessor processor= new RenamePackageProcessor(fragment);
@@ -341,7 +341,7 @@ public class RenameSupport {
/** Flag indicating that references are to be updated as well. */
public static final int UPDATE_REFERENCES = 1 << 0;
- private RenameSupport(DartRenameProcessor processor, String newName, int flags) {
+ private RenameSupport_OLD(DartRenameProcessor processor, String newName, int flags) {
fRefactoring = new RenameRefactoring(processor);
initialize(processor, newName, flags);
}
@@ -402,7 +402,7 @@ public class RenameSupport {
if (!showPreviewOnly) {
starter = RenameUserInterfaceManager.getDefault().getStarter(fRefactoring);
} else {
- starter = new RenameUserInterfaceStarter();
+ starter = new RenameUserInterfaceStarter_OLD();
RenameRefactoringWizard wizard = new RenameRefactoringWizard(
fRefactoring,
fRefactoring.getName(),
@@ -112,10 +112,10 @@ public class RenameSupport {
* <code>UPDATE_REFERENCES</code>, and <code>UPDATE_TEXTUAL_MATCHES</code>, or their
* bitwise OR, or <code>NONE</code>.
- * @return the {@link RenameSupport}.
- * @throws CoreException if an unexpected error occurred while creating the {@link RenameSupport}.
+ * @return the {@link RenameSupport_OLD}.
+ * @throws CoreException if an unexpected error occurred while creating the {@link RenameSupport_OLD}.
*/
@@ -180,10 +180,10 @@ public class RenameSupport {
* @param flags flags controlling additional parameters. Valid flags are
* <code>UPDATE_REFERENCES</code> or <code>NONE</code>.
- * @return the {@link RenameSupport}.
- * @throws CoreException if an unexpected error occurred while creating the {@link RenameSupport}.
+ * @return the {@link RenameSupport_OLD}.
+ * @throws CoreException if an unexpected error occurred while creating the {@link RenameSupport_OLD}.
*/
@@ -209,10 +209,10 @@ public class RenameSupport {
* @param newName the variable's new name. <code>null</code> is a valid value indicating that no
* new name is provided.
- * @return the {@link RenameSupport}.
- * @throws CoreException if an unexpected error occurred while creating the {@link RenameSupport}.
+ * @return the {@link RenameSupport_OLD}.
+ * @throws CoreException if an unexpected error occurred while creating the {@link RenameSupport_OLD}.
*/
@@ -265,12 +265,12 @@ public class RenameSupport {
* @param newName the type's new name. <code>null</code> is a valid value indicating that no new
* name is provided.
- * @return the {@link RenameSupport}.
- * @throws CoreException if an unexpected error occurred while creating the {@link RenameSupport}.
+ * @return the {@link RenameSupport_OLD}.
+ * @throws CoreException if an unexpected error occurred while creating the {@link RenameSupport_OLD}.
*/
@@ -306,8 +306,8 @@ public class RenameSupport {
* <code>UPDATE_REFERENCES</code>, and <code>UPDATE_TEXTUAL_MATCHES</code>, or their
* bitwise OR, or <code>NONE</code>.
- * @return the {@link RenameSupport}.
- * @throws CoreException if an unexpected error occurred while creating the {@link RenameSupport}.
+ * @return the {@link RenameSupport_OLD}.
+ * @throws CoreException if an unexpected error occurred while creating the {@link RenameSupport_OLD}.
*/
// public static RenameSupport create(IPackageFragment fragment, String newName, int flags) throws CoreException {

Powered by Google App Engine
This is Rietveld 408576698